@@ -145,12 +145,12 @@ class ResourceFactory:
         cls_name = resource_name
         if service_context.service_name == resource_name:
             cls_name = 'ServiceResource'
-        cls_name = service_context.service_name + '.' + cls_name
+        cls_name = f"{service_context.service_name}.{cls_name}"
 
         base_classes = [ServiceResource]
         if self._emitter is not None:
             self._emitter.emit(
-                'creating-resource-class.%s' % cls_name,
+                f'creating-resource-class.{cls_name}',
                 class_attributes=attrs,
                 base_classes=base_classes,
                 service_context=service_context,
@@ -325,7 +325,7 @@ class ResourceFactory:
             # identifiers have a value ``None``. If any are ``None``,
             # a more informative user error than a generic AttributeError
             # is raised.
-            return getattr(self, '_' + identifier.name, None)
+            return getattr(self, f"_{identifier.name}", None)
 
         get_identifier.__name__ = str(identifier.name)
         get_identifier.__doc__ = docstring.IdentifierDocstring(
@@ -344,7 +344,7 @@ class ResourceFactory:
         """
 
         def get_identifier(self):
-            return getattr(self, '_' + identifier.name, None)
+            return getattr(self, f"_{identifier.name}", None)
 
         get_identifier.__name__ = str(identifier.member_name)
         get_identifier.__doc__ = docstring.AttributeDocstring(
@@ -370,6 +370,7 @@ class ResourceFactory:
         Creates a new property on the resource to lazy-load its value
         via the resource's ``load`` method (if it exists).
         """
+
         # The property loader will check to see if this resource has already
         # been loaded and return the cached value if possible. If not, then
         # it first checks to see if it CAN be loaded (raise if not), then
@@ -564,7 +565,7 @@ class ResourceFactory:
                 response = action(self, *args, **kwargs)
                 self.meta.data = response
 
-            # Create the docstring for the load/reload mehtods.
+            # Create the docstring for the load/reload methods.
             lazy_docstring = docstring.LoadReloadDocstring(
                 action_name=action_model.name,
                 resource_name=resource_name,
